==> kubernetes-model-policy-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/SELinuxStrategyOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.SELinuxOptions;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SELinuxStrategyOptionsFluent<A extends SELinuxStrategyOptionsFluent<A>> extends BaseFluent<A>{
  public SELinuxStrategyOptionsFluent() {
  }
  
  public SELinuxStrategyOptionsFluent(SELinuxStrategyOptions instance) {
    this.copyInstance(instance);
  }
  private String rule;
  private SELinuxOptions seLinuxOptions;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SELinuxStrategyOptions instance) {
    instance = (instance != null ? instance : new SELinuxStrategyOptions());
  
    if (instance != null) {
        this.withRule(instance.getRule());
        this.withSeLinuxOptions(instance.getSeLinuxOptions());
        this.withRule(instance.getRule());
        this.withSeLinuxOptions(instance.getSeLinuxOptions());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getRule() {
    return this.rule;
  }
  
  public A withRule(String rule) {
    this.rule=rule; return (A) this;
  }
  
  public boolean hasRule() {
    return this.rule != null;
  }
  
  public SELinuxOptions getSeLinuxOptions() {
    return this.seLinuxOptions;
  }
  
  public A withSeLinuxOptions(SELinuxOptions seLinuxOptions) {
    this.seLinuxOptions=seLinuxOptions; return (A) this;
  }
  
  public boolean hasSeLinuxOptions() {
    return this.seLinuxOptions != null;
  }
  
  public A withNewSeLinuxOptions(String level,String role,String type,String user) {
    return (A)withSeLinuxOptions(new SELinuxOptions(level, role, type, user));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SELinuxStrategyOptionsFluent that = (SELinuxStrategyOptionsFluent) o;
    if (!java.util.Objects.equals(rule, that.rule)) return false;
  
    if (!java.util.Objects.equals(seLinuxOptions, that.seLinuxOptions)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(rule,  seLinuxOptions,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (rule != null) { sb.append("rule:"); sb.append(rule + ","); }
    if (seLinuxOptions != null) { sb.append("seLinuxOptions:"); sb.append(seLinuxOptions + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> kubernetes-model-policy-6.9.1-sources.jar: io/fabric8/kubernetes/api/model/policy/v1beta1/SELinuxStrategyOptionsFluent.java <==
package io.fabric8.kubernetes.api.model.policy.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.model.SELinuxOptions;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class SELinuxStrategyOptionsFluent<A extends SELinuxStrategyOptionsFluent<A>> extends BaseFluent<A>{
  public SELinuxStrategyOptionsFluent() {
  }
  
  public SELinuxStrategyOptionsFluent(SELinuxStrategyOptions instance) {
    this.copyInstance(instance);
  }
  private String rule;
  private SELinuxOptions seLinuxOptions;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(SELinuxStrategyOptions instance) {
    instance = (instance != null ? instance : new SELinuxStrategyOptions());
    if (instance != null) {
          this.withRule(instance.getRule());
          this.withSeLinuxOptions(instance.getSeLinuxOptions());
          this.withRule(instance.getRule());
          this.withSeLinuxOptions(instance.getSeLinuxOptions());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getRule() {
    return this.rule;
  }
  
  public A withRule(String rule) {
    this.rule = rule;
    return (A) this;
  }
  
  public boolean hasRule() {
    return this.rule != null;
  }
  
  public SELinuxOptions getSeLinuxOptions() {
    return this.seLinuxOptions;
  }
  
  public A withSeLinuxOptions(SELinuxOptions seLinuxOptions) {
    this.seLinuxOptions = seLinuxOptions;
    return (A) this;
  }
  
  public boolean hasSeLinuxOptions() {
    return this.seLinuxOptions != null;
  }
  
  public A withNewSeLinuxOptions(String level,String role,String type,String user) {
    return (A)withSeLinuxOptions(new SELinuxOptions(level, role, type, user));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SELinuxStrategyOptionsFluent that = (SELinuxStrategyOptionsFluent) o;
    if (!java.util.Objects.equals(rule, that.rule)) return false;
    if (!java.util.Objects.equals(seLinuxOptions, that.seLinuxOptions)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(rule,  seLinuxOptions,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (rule != null) { sb.append("rule:"); sb.append(rule + ","); }
    if (seLinuxOptions != null) { sb.append("seLinuxOptions:"); sb.append(seLinuxOptions + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
